@@ -62,14 +62,22 @@ seasadj <- function(object)
     else if(is.element("tbats",class(object)))
     {
       comp <- tbats.components(object)
-      sa <- comp[,"observed"]-comp[,"season"]
+      scols <- grep("season",colnames(comp))
+      sa <- comp[,"observed"]-rowSums(comp[,scols,drop=FALSE])
       # Back transform if necessary
       if (!is.null(object$lambda)) 
         sa <- InvBoxCox(sa, object$lambda)
       return(sa)
     }
+    else if(is.element("bats",class(object)))
+    {
+      if(is.null(object$gamma.values))
+        stop("There are no seasonal components in the series.")
+      else
+        stop("No seasonal adjustment available for BATS models")
+    }
     else
-        stop("Object of unknown class")
+      stop("I don't know how to seasonally adjust objects of this type")
 }
 
 seasonaldummy <- function(x)
